"""
:author: Thomas Delaet <thomas@delaet.org>
"""
# pylint: disable-msg=C0301
from domipy.modules.ddim01 import DDIM01Module
from domipy.modules.dism0x import DISM04Module
from domipy.modules.dism0x import DISM08Module
from domipy.modules.do import DBIR01Module
from domipy.modules.do import DTRP01Module
from domipy.modules.do import DTRP02Module
from domipy.modules.do import DTRV01Module
from domipy.modules.do import DTRVBT01Module
from domipy.modules.do import DFAN01Module
from domipy.modules.do import DMR01Module
from domipy.modules.do import DLED01Module
from domipy.modules.dpbu0x import DPBU01Module
from domipy.modules.dpbu0x import DPBU02Module
from domipy.modules.dpbu0x import DPBU04Module
from domipy.modules.dpbu0x import DPBU06Module
from domipy.modules.dtemp import DTEM01Module
from domipy.modules.dtemp import DTEM02Module
 